#!/usr/bin/perl
#
#  Script to uncompress the hourly tcpdump data files, put them all
#  back into one giant file and then create separate files for the
#  major protocols.
#  
#  Written by Bill Ralph 3/17/98
#
# Set up some variables.
#
$ENV{PATH} = "/bin:/usr/bin:/usr/sbin:/usr/local/bin:/usr/local/logger";
$clean_date=`date +%y%m%d -d "3 days 15 min ago"`;
chomp($clean_date);
$logger_location="NSWC";
$filters="/usr/local/logger/filters";
$subdir=`date -d $clean_date +%h%d`;
chomp($subdir);
#
sub usage {
        print "Usage: consolidate -debug -d SNIFDATE -l LOGGER_LOCATION.\n";
	exit 2;
}
#
#  Rid ourselves of standard output and error to prevent tons of mail messages
#  from cron.
#
if ( not $debug )
{
   open(STDOUT, ">>/tmp/consolidate.log");
   open(STDERR, ">&STDOUT");
   select STDERR; $| = 1;              # make unbuffered
   select STDOUT; $| = 1;              # make unbuffered
}
#
# Writer a marker to the log file.
#
$date=`date`;
chomp $date;
print STDOUT $date;
foreach $param ($0, @ARGV) {
   printf " %s", $param;
}
print STDOUT "\n";
#
#	Parse the parameters.
#
#
use Getopt::Long;
&GetOptions("debug", \$debug, "d:s", \$snifdate, "l:s", \$logger_location);
##
#
#  Check parameter validity.
#
if ("$logger_location" eq "")
{
	usage();
}
#
if ($debug)
{
   print "d = $snifdate \n";
   print "l = $logger_location \n";
}
#
# If we have been called with a SNIFDATE parameter, reset the $subdir variable.
#
if ($snifdate ne "") {
   $subdir=`date -d $snifdate +%h%d`;
   chomp($subdir);
   if ($debug)
   {
      print STDOUT "subdir = $subdir\n";
   }
}
#
# Ready to start the work now, find the hourly data files.
#
print STDOUT ("/LOG/$logger_location/$subdir\n");
#
# unzip the hourly data files.
#
#
#
chdir("/LOG/$logger_location/$subdir");
@files=<tcp.*.gz>;
if ($files[0] eq "") {
   print STDOUT ("No zipped hourly files found, moving on.\n");
} else {
   foreach $file (@files) {
      if ($debug) {
         print STDOUT ("Unzipping $file\n");
      }
      system("gunzip -f $file") == 0 or unlink($file);
   }
}
#
#  Build an entire day file from the hourly pieces.
#
if (! -e "day_whole") {
   print STDOUT ("tcpslice tcp.* > day_whole\n");
   system("tcpslice tcp.* > day_whole") == 0 or die "tcpslice failed: $?";
}
#
#  Remove the hourly pieces
#
@files=<tcp.*>;
if ($files[0] ne "") {
   foreach $file (@files) {
#     print STDOUT ("Removing $file\n");
      unlink($file) or die "Unable to remove $file:$?";
   }
} else {
   print STDOUT ("No unzipped hourly files found.\n");
}
#
#  Separate the whole day into tcp, udp, icmp, and everything_else pieces.
#
if (! -e "day_tcp") {
   system("tcpdump -r day_whole -w day_tcp -F $filters/tcp-connections") == 0 or die "tcpdump failed on tcp-connections: $?";
   print STDOUT ("tcpdump -r day_whole -w day_tcp -F $filters/tcp-connections\n");
}
if (! -e "day_udp") {
   system("tcpdump -r day_whole -w day_udp -F $filters/udp") == 0 or die "tcpdump failed on udp: $?";
   print STDOUT ("tcpdump -r day_whole -w day_udp -F $filters/udp\n");
}
if (! -e "day_icmp") {
   system("tcpdump -r day_whole -w day_icmp -F $filters/icmp") == 0 or die "tcpdump failed on icmp: $?";
   print STDOUT ("tcpdump -r day_whole -w day_icmp -F $filters/icmp\n");
}
if (! -e "day_else") {
   system("tcpdump -r day_whole -w day_else -F $filters/everything-else") == 0 or die "tcpdump failed on everything-else: $?";
   print STDOUT ("tcpdump -r day_whole -w day_else -F $filters/everything-else\n");
}
#
#  Now compress the remains.
#
system("gzip -f day_tcp")== 0 or print STDOUT "gzip failed on day_tcp.\n";
system("gzip -f day_udp")== 0 or print STDOUT "gzip failed on day_udp.\n";
system("gzip -f day_icmp")== 0 or print STDOUT "gzip failed on day_icmp.\n";
system("gzip -f day_else")== 0 or print STDOUT "gzip failed on day_else.\n";
unlink(day_whole) or print STDOUT "unlink failed on day_whole.\n";
