#!/usr/bin/perl
#
#  Script to fetch tcpdump gzipped hourly logfiles from a sensor,
#  move them to an dated subdirectory on the analyzer, run through
#  a filter looking for suspicious events, and position that suspicious
#  events text file on a web page.
#  
#  Written by Bill Ralph 3/12/98
#
# Set up some variables.
#
$ENV{PATH} = "/bin:/usr/bin:/usr/sbin:/usr/local/bin:/usr/local/logger";
$logger_location="NSWC";
$logger_name="firewall";
$web_server="apollo13";
$sensor_dir="/LOG";
$output_dir="/home/httpd/html/tcpdump_results/$logger_location";
$URL_output_dir="/tcpdump_results/$logger_location";
$filters="/usr/local/logger/filters";
#
sub usage {
        print "Usage: fetchem -debug -d SNIFDATE -l LOGGER_LOCATION -n LOGGER_NAME.\n";
	exit 2;
}
#
#	Parse the parameters.
#
#
use Getopt::Long;
&GetOptions("debug", \$debug, "d:s", \$snifdate, "l:s", \$logger_location, "n:s", \$logger_name);
##
#
#  Rid ourselves of standard output and error to prevent tons of mail messages
#  from cron.
#
if ( not $debug )
{
   open(STDOUT, ">>/tmp/fetchem.log");
   open(STDERR, ">&STDOUT");
   select STDERR; $| = 1;              # make unbuffered
   select STDOUT; $| = 1;              # make unbuffered
}
#
# Writer a marker to the log file.
#
$date=`date`;
chomp $date;
print STDOUT $date;
foreach $param ($0, @ARGV) {
   printf " %s", $param;
}
print STDOUT "\n";
#
#  Check parameter validity.
#
if ("$logger_location" eq "" or "$logger_name" eq "")
{
	usage();
}
#
#
#  Add the logger_location component to the web page path.
#
$output_dir="/home/httpd/html/tcpdump_results/$logger_location";
$URL_output_dir="/tcpdump_results/$logger_location";
#
# If we have been called with a SNIFDATE parameter, set up the $dir variable,
# else download the SNIFDATE from the sensor.
#
if ($snifdate eq "") {
   $snif_file="/tmp/" . $logger_location . "_snif.date";
   if ($debug) {
      print STDOUT "SNIF file = $snif_file \n";
   }
   if ( -f $snif_file) {
      unlink $snif_file;
   }
   print STDOUT ("scp $logger_name:/LOG/snif.date.0 $snif_file\n");
   system("scp $logger_name:/LOG/snif.date.0 $snif_file");
   $snifdate=`cat $snif_file`;
   chomp($snifdate);
}
#
#  Break up the "snifdate" into its useful components.
#
$sn1=substr($snifdate,0,-2);
$hour=substr($snifdate,-2,2).":00";
$newdate="$sn1 $hour";
$dir=`date -d $sn1 +%h%d`;
chomp($dir);
$yester_dir = `date -d "$dir 1 day ago" +%h%d`;
chomp($yester_dir);
$tomorrow_dir = `date -d "$dir + 1 day" +%h%d`;
chomp($tomorrow_dir);
if ($debug) {
   print STDOUT "snifdate = $snifdate, sn1 = $sn1, dir = $dir, hour = $hour\n";
   print STDOUT "newdate = $newdate\n";
}
#
# Predict the previous hour and next hour for html links.
#
$last_hour = `date -d "$newdate 1 hour ago" +%y%m%d%H`;
chomp($last_hour);
$last_hour_dir = `date -d "$newdate 1 hour ago" +%h%d`;
chomp($last_hour_dir);
$next_hour  = `date -d "$newdate + 1 hour"  +%y%m%d%H`;
chomp($next_hour);
$next_hour_dir = `date -d "$newdate + 1 hour" +%h%d`;
chomp($next_hour_dir);
if ($debug) {
   print STDOUT "Last HR. = $last_hour, Next HR. = $next_hour\n";
   print STDOUT "Last HR/dir = $last_hour_dir, Next HR/dir = $next_hour_dir\n";
}
#
#  Make sure subdirectory "MONXX" exists under /LOG/$logger_location and
#  on web page
#
unless ( -d "/LOG/$logger_location/$dir") {
   mkdir("/LOG/$logger_location/$dir", 0755) 
    or die "Unable to mkdir /LOG/$logger_location/$dir: $?";
}
unless ( -d "/$output_dir/$dir") {
   mkdir("/$output_dir/$dir", 0755) 
    or die "Unable to mkdir /$output_dir/$dir";
#
#  Create the index for the day represented by the directory we just 
#  created. The index.html files will be a page listing one html file for
#  each hour of the day - prettified a tiny bit.
#
   chdir("/$output_dir/$dir");
   open(DAYINDEX, ">index.html");
   print DAYINDEX <<"EOF";
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0 Final//EN">
<HTML>
<HEAD><TITLE>Daily TCPDUMP Files for $dir
</TITLE>
</HEAD>
<BODY CLEAR=BOTH BACKGROUND="/images/legalpad.GIF">
<H2>Hourly TCPDUMP results for $dir</H$>
<UL TYPE=DISC> 
<FONT SIZE=+1>
<LI><A HREF="$URL_output_dir/$dir/00.html">Midnight till 1 AM</A></LI> 
<LI><A HREF="$URL_output_dir/$dir/01.html">Between 1 and 2 AM</A></LI> 
<LI><A HREF="$URL_output_dir/$dir/02.html">Between 2 and 3 AM</A></LI> 
<LI><A HREF="$URL_output_dir/$dir/03.html">Between 3 and 4 AM</A></LI> 
<LI><A HREF="$URL_output_dir/$dir/04.html">Between 4 and 5 AM</A></LI> 
<LI><A HREF="$URL_output_dir/$dir/05.html">Between 5 and 6 AM</A></LI> 
<LI><A HREF="$URL_output_dir/$dir/06.html">Between 6 and 7 AM</A></LI> 
<LI><A HREF="$URL_output_dir/$dir/07.html">Between 7 and 8 AM</A></LI> 
<LI><A HREF="$URL_output_dir/$dir/08.html">Between 8 and 9 AM</A></LI> 
<LI><A HREF="$URL_output_dir/$dir/09.html">Between 9 and 10 AM</A></LI> 
<LI><A HREF="$URL_output_dir/$dir/10.html">Between 10 and 11 AM</A></LI> 
<LI><A HREF="$URL_output_dir/$dir/11.html">Between 11 AM and Noon</A></LI> 
<LI><A HREF="$URL_output_dir/$dir/12.html">Lunch</A></LI> 
<LI><A HREF="$URL_output_dir/$dir/13.html">Between 1 and 2 PM</A></LI> 
<LI><A HREF="$URL_output_dir/$dir/14.html">Between 2 and 3 PM</A></LI> 
<LI><A HREF="$URL_output_dir/$dir/15.html">Between 3 and 4 PM</A></LI> 
<LI><A HREF="$URL_output_dir/$dir/16.html">Between 4 and 5 PM</A></LI> 
<LI><A HREF="$URL_output_dir/$dir/17.html">Between 5 and 6 PM</A></LI> 
<LI><A HREF="$URL_output_dir/$dir/18.html">Between 6 and 7 PM</A></LI> 
<LI><A HREF="$URL_output_dir/$dir/19.html">Between 7 and 8 PM</A></LI> 
<LI><A HREF="$URL_output_dir/$dir/20.html">Between 8 and 9 PM</A></LI> 
<LI><A HREF="$URL_output_dir/$dir/21.html">Between 9 and 10 PM</A></LI> 
<LI><A HREF="$URL_output_dir/$dir/22.html">Between 10 and 11 PM</A></LI> 
<LI><A HREF="$URL_output_dir/$dir/23.html">Between 11 PM and Midnight</A></LI> 
</FONT>
</UL>

<TABLE CELLSPACING="0" CELLPADDING="0">
<TR>
<TD ALIGN=CENTER VALIGN=MIDDLE><A HREF="$URL_output_dir/$yester_dir/index.html"><IMG SRC="/images/navbars/2/1.gif" WIDTH="90" HEIGHT="20" BORDER="0" HSPACE="0" VSPACE="0"></A><IMG SRC="/images/navbars/2/2.gif" WIDTH="110" HEIGHT="20" HSPACE="0" VSPACE="0"><A HREF="/tcpdump_results/index.html"><IMG SRC="/images/navbars/2/3.gif" WIDTH="50" HEIGHT="20" BORDER="0" HSPACE="0" VSPACE="0"></A><IMG SRC="/images/navbars/2/2.gif" WIDTH="110" HEIGHT="20" HSPACE="0" VSPACE="0"><A HREF="$URL_output_dir/$tomorrow_dir/index.html"><IMG SRC="/images/navbars/2/5.gif" WIDTH="90" HEIGHT="20" BORDER="0" HSPACE="0" VSPACE="0"></A></TD></TR>
</TABLE>
</BODY>
</HTML>
EOF
   close(DAYINDEX);
}
#
# Copy down the raw gzipped tcpdump data file.
#
unless ( -f "/LOG/$logger_location/$dir/tcp.$snifdate.gz" ) {
      print STDOUT ("scp $logger_name:/LOG/tcp.$snifdate.gz /LOG/$logger_location/$dir\n");
      system("scp $logger_name:/LOG/tcp.$snifdate.gz /LOG/$logger_location/$dir");
}
#
#  Call tcpdump to read the newly fetched file, scan it with our bad guys
#  filter, and write the results to the web page.
#
$zipped_file="/LOG/".$logger_location."/".$dir."/tcp.".$snifdate.".gz";
$filter=$filters."/".$logger_location."_bad_events";
$output_txt_file="$output_dir/$dir/$snifdate.txt";
$output_html_file="$output_dir/$dir/$snifdate.html";
$prev_out_file="$URL_output_dir/$last_hour_dir/$last_hour.html";
$next_out_file="$URL_output_dir/$next_hour_dir/$next_hour.html";
if ($debug) {
   print STDOUT "zip file = $zipped_file\nfilters = $filter\n";
   print STDOUT "output = $output_txt_file\nprev = $prev_out_file\n";
   print STDOUT "output = $output_html_file\nprev = $next_out_file\n";
}
$hour_only = substr($hour,0,2);
open(OUTPUT, ">$output_html_file");
print OUTPUT <<"EOF";
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0 Final//EN">
<HTML>
<HEAD>
<TITLE>Hourly tcpdump for $logger_location on $dir at $hour.</TITLE>
</HEAD>
<BODY BGCOLOR='ffdead'> 
<PRE>
EOF
close(OUTPUT);
if (not -e $output_txt_file) {
   print STDOUT ("gunzip -c $zipped_file | tcpdump -r - -F $filter > $output_file\n");
   system("gunzip -c $zipped_file | tcpdump -r - -F $filter > $output_txt_file");
}
print STDOUT "Copying $output_txt_file to $output_html_file.\n";
open(OUTPUT, ">>$output_html_file") or die "Can't open $output_html_file";
open(TEXTFILE, "<$output_txt_file") or die "Can't open $output_txt_file";
while (<TEXTFILE>) {
   print OUTPUT $_;
}
close(TEXTFILE);
print OUTPUT <<"EOF";
</PRE>
<HR>
<TABLE CELLSPACING="0" CELLPADDING="0">
<TR>
<TD ALIGN=CENTER VALIGN=MIDDLE><A HREF="$prev_out_file"><IMG SRC="/images/navbars/2/1.gif" WIDTH="90" HEIGHT="20" BORDER="0" HSPACE="0" VSPACE="0"></A><IMG SRC="/images/navbars/2/2.gif" WIDTH="110" HEIGHT="20" HSPACE="0" VSPACE="0"><A HREF="$URL_output_dir/$dir/index.html"><IMG SRC="/images/navbars/2/3.gif" WIDTH="50" HEIGHT="20" BORDER="0" HSPACE="0" VSPACE="0"></A><IMG SRC="/images/navbars/2/2.gif" WIDTH="110" HEIGHT="20" HSPACE="0" VSPACE="0"><A HREF="$next_out_file"><IMG SRC="/images/navbars/2/5.gif" WIDTH="90" HEIGHT="20" BORDER="0" HSPACE="0" VSPACE="0"></A></TD></TR>
</TABLE>

</BODY>
</HTML>
EOF
close(OUTPUT);
#
# Create the symbolic link for the html HR.html file.
#
print STDOUT "Creating symbolic link $output_dir/$dir/$hour_only.html -> $output_html_file\n.";
symlink($output_html_file, "$output_dir/$dir/$hour_only.html");
#
# Call script to ship the file to the SHADOW secondary analysis machine.
#
print STDOUT "Shipping files to Lotus. Fetchem completed.\n";
exec("perl /usr/local/logger/translate.pl -d $snifdate -l $logger_location");
